@@ -414,7 +414,7 @@ macro_rules! impl_fixed_types {
                             )));
                         }
 
-                        let mut arr = ArrayVec::<[T; $num]>::new();
+                        let mut arr = ArrayVec::<T, $num>::new();
                         let mut it = tokens.into_iter().map(T::from_token);
                         for _ in 0..$num {
                             arr.push(it.next().expect("Length validated in guard; qed")?);
